<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\dto\handlerConfigParams;

use apexl\Io\modules\logger\dto\handlerConfigParams;

class logstashHandlerConfigParams extends handlerConfigParams
{
    public string $host = 'localhost';
    public int $port = 50000;
    public ?string $application;
    public ?string $system;
}
