<?php

declare(strict_types=1);

use apexl\Config\ConfigurationInterface;
use apexl\Io\modules\logger\dto\LoggerConfig;
use function DI\factory;

return [
    LoggerConfig::class => factory(fn(ConfigurationInterface $config): LoggerConfig =>  LoggerConfig::fromConfig($config)),
];
