<?php

/** @noinspection PhpMissingFieldTypeInspection */
declare(strict_types=1);

namespace apexl\Io\modules\logger\dto;

use apexl\Io\modules\logger\enums\LogLevel;
use Spatie\DataTransferObject\DataTransferObject;

class handlerConfig extends DataTransferObject
{
    public string $destination;
    public LogLevel $level;
    public $params;
}
