<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\dto;

use Spatie\DataTransferObject\DataTransferObjectCollection;

/**
 * @method handlerConfig current
 */
class handlerConfigCollection extends DataTransferObjectCollection
{
}
