<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\services\handlerCreator;

use apexl\Io\modules\logger\dto\handlerConfig;
use apexl\Io\modules\logger\dto\streamConfig;
use apexl\Io\modules\logger\interfaces\handlerCreatorInterface;

abstract readonly class handlerCreator implements handlerCreatorInterface
{
    protected function level(
        handlerConfig $handlerConfig,
        streamConfig $streamConfig,
    ): string {
        return ($handlerConfig->level ?? $streamConfig->level)->value;
    }
}