<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\dto\handlerConfigParams;

use apexl\Io\modules\logger\dto\handlerConfigParams;

class fileHandlerConfigParams extends handlerConfigParams
{
    public ?string $file;
    public int $maxFiles = 7;
}
