<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\dto\handlerConfigParams;

use apexl\Io\modules\logger\dto\handlerConfigParams;

class databaseHandlerConfigParams extends handlerConfigParams
{
    public string $table;
}
