<?php

declare(strict_types=1);

namespace apexl\Io\modules\logger\interfaces;

use apexl\Io\modules\logger\dto\handlerConfig;
use apexl\Io\modules\logger\dto\streamConfig;
use Monolog\Handler\HandlerInterface;

interface handlerCreatorInterface
{
    public function create(
        string $streamName,
        handlerConfig $handlerConfig,
        streamConfig $streamConfig,
    ): HandlerInterface;
}
